Learn R Programming

dobson (version 0.4.1)

Cars: Cars data from table 8.1

Description

Preferences for air conditioning and power steering in cars by gender and age.

Usage

data(Cars)

Arguments

Format

A tibble with 18 observations and the following 4 variables.

sex

sex

age

age group (3 levels)

response

ordinal response (3 levels)

frequency

frequency

References

McFadden, M., J. Powers, W. Brown, and M. Walker (2000). Vehicle and driver attributes affecting distance from the steering wheel in motor vehicles. Human Factors 42, 676–682.

Examples

Run this code
data(Cars)
summary(Cars)

Run the code above in your browser using DataLab