Learn R Programming

dobson (version 0.4.1)

anthers: Embryogenic anthers data from table 7.5

Description

Numbers of embryogenic anthers of the plant species Datura innoxia Mill obtained when anthers were prepared under several different conditions

Usage

data(anthers)

Arguments

Format

A tibble with 6 observations and the following 4 variables.

y

numbers of embryogenic anthers

n

number of anthers

newstor

storage condition, 0 = control or 1 = treatment

x

log (base e) of centrifuging force (g)

References

Sangwan-Norrell, B. S. (1977). Androgenic stimulating factor in the anther and isolated pollen grain culture of Datura innoxia mill. Journal of Experimental Biology 28, 843–852.

Examples

Run this code
data(anthers)
summary(anthers)

Run the code above in your browser using DataLab