Learn R Programming

dobson (version 0.4.1)

doctors: Doctors data from table 9.1

Description

Data from the famous doctors study of smoking conducted by Sir Richard Doll and colleagues

Usage

data(doctors)

Arguments

Format

A tibble with 10 observations and the following 5 variables.

age

age group; 1 = 35 to 44 years, 2 = 45 to 54 years, 3 = 55 to 64 years, 4 = 65 to 74 years, 5 = 75 to 84 years

agesq

age group squared

smoking

smoker or non-smoker

deaths

number of deaths

personyears

person years of observation at the time of the analysis

References

Breslow, N. E. and N. E. Day (1987). Statistical Methods in Cancer Research, Volume 2: The Design and Analysis of Cohort Studies. Lyon: International Agency for Research on Cancer.

Examples

Run this code
data(doctors)
summary(doctors)

Run the code above in your browser using DataLab