Learn R Programming

dobson (version 0.4.1)

ear: Ears data from table 11.10

Description

Numbers of ears clear of acute otitis media at 14 days by antibiotic treatment and age of the child. The children had acute otitis media in both ears.

Usage

data(ear)

Arguments

Format

A tibble with 18 observations and the following 4 variables.

age

child's age (3 levels)

treatment

two treatments coded CEF and AMO

number clear

number of clear ears (0, 1 or 2)

frequency

number of children

References

Rosner, B. (1989). Multivariate methods for clustered binary data with more than one level of nesting. Journal of the American Statistical Association 84, 373–380.

Examples

Run this code
data(ear)
summary(ear)

Run the code above in your browser using DataLab