Learn R Programming

dobson (version 0.4.1)

failure: Failure time data from table 4.1

Description

Lifetimes of Kevlar epoxy strand pressure vessels at 70 percent stress level

Usage

data(failure)

Arguments

Format

A tibble with 49 observations and the following variable.

lifetimes

time to failure in hours

References

Andrews, D. F. and A. M. Herzberg (1985). Data: A Collection of Problems from Many Fields for the Student and Research Worker. New York: Springer Verlag.

Examples

Run this code
data(failure)
summary(failure)

Run the code above in your browser using DataLab