Learn R Programming

dobson (version 0.4.1)

melanoma: Melanoma data from table 9.4

Description

A cross-sectional study of patients with a form of skin cancer called malignant melanoma

Usage

data(melanoma)

Arguments

Format

A tibble with 12 observations and the following 3 variables.

tumor

tumor type (4 levels)

site

site of cancer (4 levels)

frequency

number of melanomas

References

Roberts, G., A. L. Martyn, A. J. Dobson, and W. H. McCarthy (1981). Tumour thickness and histological type in malignant melanoma in New South Wales, Australia, 1970–76. Pathology 13, 763--770.

Examples

Run this code
data(melanoma)
summary(melanoma)

Run the code above in your browser using DataLab