Learn R Programming

dobson (version 0.4.1)

senility: Senility data from table 7.8

Description

Data from a sample of elderly people given a psychiatric examination to determine whether symptoms of senility were present together with their score on a subset of the Wechsler Adult Intelligent Scale (WAIS).

Usage

data(senility)

Arguments

Format

A tibble with 54 observations and the following 2 variables.

x

WAIS score

s

symptoms of senility present; 1 = yes, 0 = no

Examples

Run this code
data(senility)
summary(senility)

Run the code above in your browser using DataLab