Learn R Programming

dobson (version 0.4.1)

stroke.wide: Stroke data from table 11.1 in wide format

Description

Longitudinal data from an experiment to promote the recovery of stroke patients in wide format. The response variable is the Bartel index with higher scores meaning better outcomes and a maximum score of 100.

Usage

data(stroke.wide)

Arguments

Format

A tibble with 24 observations and the following 10 variables.

Subject

Subject number

Group

group; A = new occupational therapy intervention, B = existing stroke rehabilitation program in the same hospital as group A, C = usual care in a different hospital

week1

Bartel index in week 1

week2

Bartel index in week 2

week3

Bartel index in week 3

week4

Bartel index in week 4

week5

Bartel index in week 5

week6

Bartel index in week 6

week7

Bartel index in week 7

week8

Bartel index in week 8

References

C. Cropper, University of Queensland

Examples

Run this code
data(stroke.wide)
summary(stroke.wide)

# Transform data from wide to long format
stroke = tidyr::pivot_longer(data=stroke.wide, cols = !c('Subject','Group'), 
  values_to='ability', names_to='week') 
stroke = dplyr::mutate(stroke, week = as.numeric(gsub('week', '', week)))

Run the code above in your browser using DataLab