Learn R Programming

dobson (version 0.4.1)

tumor: Tumor data from table 8.6

Description

Tumor responses of male and female patients receiving treatment for small-cell lung cancer

Usage

data(tumor)

Arguments

Format

A tibble with 16 observations and the following 4 variables.

treatment

treatment; sequential or alternating

sex

sex

response

four category ordinal response

frequency

number of patients

References

Holtbrugger, W. and M. Schumacher (1991). A comparison of regression models for the analysis of ordered categorical data. Applied Statistics 40, 249--259.

Examples

Run this code
data(tumor)
summary(tumor)

Run the code above in your browser using DataLab